#!/bin/bash

# Set up prompts as functions to make it easier to make changes later on

# set version

tcversion="TorConnect V0.2"

# Check if already installed

CheckInstalled() {

	if [ -d '/etc/TorConnect/' ] && [ -e '/usr/bin/torconnect' ]

	then

		dialog --title "$tcversion Installer" \
                --msgbox "\n$tcversion is already installed on your system\n\nRun 'torconnect' on the command line in order to launch the program\n" 10 50

	        clear
       		exit 0

	fi

}

# Test if user has root before continuing and drop back to a prompt if not

UserIsRoot() {

	test "$(id -u)" = 0 || {
        
		dialog --title "$tcversion Installer" \
		--backtitle "ERROR - YOU DO NOT HAVE SUFFICIENT PRIVILEGES TO INSTALL TORCONNECT" \
		--msgbox "\nYou need to run this program with root privileges to install TorConnect V0.2.\n\nTry typing 'sudo ./install.sh' instead\n" 10 50

	clear
	exit 1

	}
}

# Check that user wishes to install before carrying on

ContinueInstallation() {

		dialog --title "TorConnect v0.2 Installer" --backtitle "TorConnect v0.2 - Cobbled together by JimDog"\
 		--yesno "\nThis program will install TorConnect V0.2 on your system. Are you sure you want to continue?\n\nPress No to exit without any change to your computer"\
		10 60

	sel=$?
		
	case $sel in

		0) ;;
		1) clear && exit 0;;
		255) clear && exit 0;;

	esac
	
}

# Create required Directories for the files to live in

CreateDirectories() {

	mkdir /etc/TorConnect
	mkdir /etc/TorConnect/bin

}

# Compile required binary files with gcc

CompileBinaries() {

	gcc src/connect.c -o /etc/TorConnect/bin/connect

}

# Copy script to correct folder and make it writeable

CopyFilesToFolder() {

	cp bin/TorConnect_0.2 /etc/TorConnect/torconnect
	chmod 555 /etc/TorConnect/torconnect

}

# Create symbolic link to /usr/bin

CreateSymLink() {

	ln -s /etc/TorConnect/torconnect /usr/bin/torconnect

}

# Begin installation program

# See if there is already an installed version

CheckInstalled

#Check root status

UserIsRoot

# Get user confirmation before continuing

ContinueInstallation

# Begin Installing files with progress bar

CreateDirectories | dialog --title "Installing TorConnect v0.2" --guage "Creating Directories to install to" 6 100 0

	sleep 0.5

CompileBinaries | dialog --title "Installing TorConnect v0.2" --guage "Compiling necessary files into correct location" 6 100 25

	sleep 0.5

CopyFilesToFolder | dialog --title "Installing TorConnect v0.2" --guage "Copying files to correct folders" 6 100 50

	sleep 0.5

CreateSymLink | dialog --title "Installing TorConnect v0.2" --guage "Creating symbolic links" 6 100 75

	sleep 0.5

echo "TorConnect V0.2 has been installed successfully" | dialog --title "Installing TorConnect v0.2" --guage "TorConnect V0.2 has been installed successfully" 6 100 100

	sleep 1

	dialog --title "TorConnect V0.2 was successfully installed"\
	--msgbox "Installation was successful. To launch the program type 'torconnect' on the command line" 6 50

	clear

	exit 0

